# Architecture Decision Records

> Document significant architecture decisions here.

---

## ADR Template

Create new files as `adr-XXX-title.md`:

```markdown
# ADR-XXX: Decision Title

## Status

Proposed / Accepted / Deprecated / Superseded

## Context

Why is this decision needed?

## Decision

What is the decision?

## Consequences

What are the results of this decision?

## Alternatives Considered

What other options were considered?
```

---

## Index

| ADR | Title | Status |
|-----|-------|--------|
| - | - | - |

---

*Add new ADRs for significant architectural decisions.*
